@@ -11,7 +11,7 @@ Dual-licensed under `MIT` or the [UNLICENSE](http://unlicense.org/).
 
 ## Usage
 
-    handlebars-magic 0.1.0
+    handlebars-magic 0.3.0
     Generates documentation from handlebars templates
 
     USAGE:
@@ -24,6 +24,48 @@ Dual-licensed under `MIT` or the [UNLICENSE](http://unlicense.org/).
     ARGS:
         <input>     The input folder with templates
         <output>    The output folder
+
+## Supported helpers
+
+### `from`
+
+Searches for the prefix and starts with it if found. Else returns the whole string.
+
+    {{ from "begin" "prefix begin text end" }}
+
+renders to:
+
+    begin text end
+
+### `render`
+
+Processes an argument as `handlebars`'s template.
+
+    {{ render "some handlebars template" }}
+
+renders to:
+
+    some handlebars template
+
+This does not look useful until we use it in conjuction with other helper such as `read_to_str` from [handlebars_misc_helpers](https://crates.io/crates/handlebars_misc_helpers):
+
+    {{ render ( read_to_str "templates/README.md" ) }}
+
+### `codeblock`
+
+Allows to insert markdown's fanced code block. Content would be trimmed.
+
+    {{ codeblock "bash" "echo test" }}
+
+renders to:
+
+    ```bash
+    echo test
+    ```
+
+### `handlebars_misc_helpers`
+
+All helpers from [handlebars_misc_helpers](https://crates.io/crates/handlebars_misc_helpers).
 */
 mod cli;
 
@@ -86,6 +128,11 @@ fn main() -> anyhow::Result<()> {
 
     handlebars.register_helper("render", Box::new(render));
 
+    handlebars_helper!(codeblock: |codeblock_type: str, block: str| {
+        format!("```{}\n{}\n```", codeblock_type, block.trim())
+    });
+    handlebars.register_helper("codeblock", Box::new(codeblock));
+
     while !dirs.is_empty() {
         let dir = dirs.pop_front().unwrap();
         for entry in dir.read_dir()? {
